@@ -12,14 +12,13 @@
  * license. Therefore any rights, title and interest in our trademarks 
  * remain entirely with us.
  * 
- * Our trademark policy, <http://www.zarafa.com/zarafa-trademark-policy>,
- * allows you to use our trademarks in connection with Propagation and 
- * certain other acts regarding the Program. In any case, if you propagate 
- * an unmodified version of the Program you are allowed to use the term 
- * "Zarafa" to indicate that you distribute the Program. Furthermore you 
- * may use our trademarks where it is necessary to indicate the intended 
- * purpose of a product or service provided you use it in accordance with 
- * honest business practices. For questions please contact Zarafa at 
+ * Our trademark policy (see TRADEMARKS.txt) allows you to use our trademarks
+ * in connection with Propagation and certain other acts regarding the Program.
+ * In any case, if you propagate an unmodified version of the Program you are
+ * allowed to use the term "Zarafa" to indicate that you distribute the Program.
+ * Furthermore you may use our trademarks where it is necessary to indicate the
+ * intended purpose of a product or service provided you use it in accordance
+ * with honest business practices. For questions please contact Zarafa at
  * trademark@zarafa.com.
  *
  * The interactive user interface of the software displays an attribution 
@@ -119,12 +118,16 @@ class PluginManager
 		// If no plugindata has been stored yet, get it from the plugins dir.
 		if(!$this->plugindata || DEBUG_PLUGINS){
 			$this->plugindata = Array();
-			$pluginsdir = opendir(PATH_PLUGIN_DIR);
-			while(($plugin = readdir($pluginsdir)) !== false){
-				if ($plugin != '.' && $plugin != '..' && !in_array($plugin, $disabledPlugins)){
-					if(is_dir(PATH_PLUGIN_DIR.'/'.$plugin)){
-						if(is_file(PATH_PLUGIN_DIR.'/'.$plugin.'/manifest.xml')){
-							$this->processPlugin($plugin);
+			if(is_dir(PATH_PLUGIN_DIR)) {
+				$pluginsdir = opendir(PATH_PLUGIN_DIR);
+				if($pluginsdir) {
+					while(($plugin = readdir($pluginsdir)) !== false){
+						if ($plugin != '.' && $plugin != '..' && !in_array($plugin, $disabledPlugins)){
+							if(is_dir(PATH_PLUGIN_DIR.'/'.$plugin)){
+								if(is_file(PATH_PLUGIN_DIR.'/'.$plugin.'/manifest.xml')){
+									$this->processPlugin($plugin);
+								}
+							}
 						}
 					}
 				}
